OC.L10N.register(
    "files",
    {
    "File could not be found" : "Tiedostoa ei löytynyt",
    "Move or copy" : "Siirrä tai kopioi",
    "Download" : "Lataa",
    "Delete" : "Poista",
    "Tags" : "Tunnisteet",
    "Show list view" : "Näytä listanäkymä",
    "Show grid view" : "Näytä ruudukkonäkymä",
    "Home" : "Koti",
    "Close" : "Sulje",
    "Favorites" : "Suosikit",
    "Could not create folder \"{dir}\"" : "Kansiota \"{dir}\" ei voitu luoda",
    "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
    "Upload cancelled." : "Lähetys peruttu.",
    "Processing files …" : "Käsitellään tiedostoja…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kohdetta {filename} ei voi lähettää, koska se on joko kansio tai sen koko on 0 tavua",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ei riittävästi vapaata tilaa. Lähetyksesi koko on {size1}, mutta vain {size2} on jäljellä",
    "Target folder \"{dir}\" does not exist any more" : "Kohdekansio \"{dir}\" ei ole enää olemassa",
    "Not enough free space" : "Ei tarpeeksi vapaata tilaa",
    "An unknown error has occurred" : "Tapahtui tuntematon virhe",
    "File could not be uploaded" : "Tiedostoa ei voi lähettää",
    "Uploading …" : "Lähetetään…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Kyseisen kohteen lähettäminen ei ole tuettu",
    "Target folder does not exist any more" : "Kohdekansiota ei ole enää olemassa",
    "Operation is blocked by access control" : "Pääsynhallinta estää toiminnon",
    "Error when assembling chunks, status code {status}" : "Virhe koottaessa lohkoja, tilakoodi {status}",
    "Actions" : "Toiminnot",
    "Rename" : "Nimeä uudelleen",
    "Move" : "Siirrä",
    "Copy" : "Kopioi",
    "Choose target folder" : "Valitse kohdekansio",
    "Edit locally" : "Muokkaa paikallisesti",
    "Open" : "Avaa",
    "Delete file" : "Poista tiedosto",
    "Delete folder" : "Poista kansio",
    "Disconnect storage" : "Katkaise yhteys tallennustilaan",
    "Leave this share" : "Poistu tästä jaosta",
    "Could not load info for file \"{file}\"" : "Ei voida ladata tiedoston \"{file}\" tietoja",
    "Files" : "Tiedostot",
    "Details" : "Tiedot",
    "Please select tag(s) to add to the selection" : "Valitse lisättävät tunnisteet valinnalle",
    "Apply tag(s) to selection" : "Hyväksy tunnisteet valinnalle",
    "Select directory \"{dirName}\"" : "Valitse kansio \"{dirName}\"",
    "Select file \"{fileName}\"" : "Valitse tiedosto \"{fileName}\"",
    "Pending" : "Odottaa",
    "Unable to determine date" : "Päivämäärän määrittäminen epäonnistui",
    "This operation is forbidden" : "Tämä toiminto on kielletty",
    "This directory is unavailable, please check the logs or contact the administrator" : "Hakemisto ei ole käytettävissä. Tarkista lokit tai ole yhteydessä ylläpitoon.",
    "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
    "Could not move \"{file}\", target exists" : "Tiedoston \"{file}\" siirtäminen ei onnistunut, kohde on olemassa",
    "Could not move \"{file}\"" : "Tiedoston \"{file}\" siirtäminen ei onnistunut",
    "copy" : "kopio",
    "Could not copy \"{file}\", target exists" : "Tiedostoa \"{file}\" ei voitu kopioida, kohde on olemassa",
    "Could not copy \"{file}\"" : "Tiedostoa \"{file}\" ei voitu kopioida",
    "Copied {origin} inside {destination}" : "Kopioitu {origin} kohteeseen {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopioitu {origin} ja {nbfiles} muuta tiedostoa kohteeseen {destination}",
    "Failed to redirect to client" : "Uudelleenohjaus asiakkaaseen epäonnistui",
    "{newName} already exists" : "{newName} on jo olemassa",
    "Could not rename \"{fileName}\", it does not exist any more" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut, koska sitä ei ole enää olemassa",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{targetName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
    "Could not rename \"{fileName}\"" : "Tiedoston \"{fileName}\" nimeäminen uudelleen ei onnistunut",
    "Could not create file \"{file}\"" : "Tiedostoa \"{file}\" ei voitu luoda",
    "Could not create file \"{file}\" because it already exists" : "Tiedostoa \"{file}\" ei voitu luoda, koska se on jo olemassa",
    "Could not create folder \"{dir}\" because it already exists" : "Kansiota \"{dir}\" ei voitu luoda, koska se on jo olemassa",
    "Could not fetch file details \"{file}\"" : "Ei voitu hakea tiedoston tietoja \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Virhe poistaessa tiedostoa \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ei hakutuloksia muissa kansioissa haulla {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Kirjoita enemmän kuin kaksi merkkiä etsiäksesi muista kansioista",
    "Name" : "Nimi",
    "Size" : "Koko",
    "Modified" : "Muokattu",
    "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
    "_%n file_::_%n files_" : ["%n tiedosto","%n tiedostoa"],
    "{dirs} and {files}" : "{dirs} ja {files}",
    "_including %n hidden_::_including %n hidden_" : ["Sisältäen %n piilotetun","Sisältäen %n piilotettua"],
    "You do not have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai luomiseen tähän sijaintiin",
    "_Uploading %n file_::_Uploading %n files_" : ["Lähetetään %n tiedosto","Lähetetään %n tiedostoa"],
    "New file/folder menu" : "Uusi tiedosto/kansio -valikko",
    "Select file range" : "Valitse tiedostojoukko",
    "{used}%" : "{used} %",
    "{used} of {quota} used" : "{used}/{quota} käytetty",
    "{used} used" : "{used} käytetty",
    "\"{name}\" is an invalid file name." : "\"{name}\" on virheellinen tiedostonimi.",
    "File name cannot be empty." : "Tiedoston nimi ei voi olla tyhjä.",
    "\"/\" is not allowed inside a file name." : "\"/\" ei ole sallittu merkki tiedostonimessä.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ei ole sallittu tiedostomuoto",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Käyttäjän {owner} tallennustila on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ryhmäkansio \"{mountPoint}\" on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Erillinen tallennustila \"{mountPoint}\" on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Tallennustilasi on täynnä, tiedostoja ei voi enää päivittää tai synkronoida!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Käyttäjän {owner} tallennustila on melkein täynnä ({usedSpacePercent} %)",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Ryhmäkansio \"{mountPoint}\" on melkein täynnä ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Erillinen tallennustila \"{mountPoint}\" on melkein täynnä ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Tallennustila on melkein täynnä ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["vastaa \"{filter}\"","vastaa \"{filter}\""],
    "View in folder" : "Näe kansiossa",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Suoralinkki kopioitiin (toimii vain niillä käyttäjillä, joilla on pääsy kyseiseen tiedostoon/kansioon)",
    "Path" : "Polku",
    "_%n byte_::_%n bytes_" : ["%n tavu","%n tavua"],
    "Favorited" : "Lisätty suosikkeihin",
    "Favorite" : "Suosikki",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopioi suora linkki (toimii vain käyttäjillä, joilla on pääsyoikeus tähän tiedostoon/kansioon)",
    "You can only favorite a single file or folder at a time" : "Voit valita suosikiksi vain yhden tiedoston tai kansion kerrallaan",
    "New folder" : "Uusi kansio",
    "Upload file" : "Lähetä tiedosto",
    "Recent" : "Viimeaikaiset",
    "Not favorited" : "Ei suosikeissa",
    "Remove from favorites" : "Poista suosikeista",
    "Add to favorites" : "Lisää suosikkeihin",
    "An error occurred while trying to update the tags" : "Tunnisteiden päivitystä yrittäessä tapahtui virhe",
    "Added to favorites" : "Lisätty suosikkeihin",
    "Removed from favorites" : "Poistettu suosikeista",
    "You added {file} to your favorites" : "Lisäsit tiedoston {file} suosikkeihin",
    "You removed {file} from your favorites" : "Poistit tiedoston {file} suosikeista",
    "File changes" : "Tiedostomuutokset",
    "Created by {user}" : "Tekijänä {user}",
    "Changed by {user}" : "Muokkaajana {user}",
    "Deleted by {user}" : "Poistanut {user}",
    "Restored by {user}" : "Palauttanut {user}",
    "Renamed by {user}" : "Uudelleennimennyt {user}",
    "Moved by {user}" : "Siirtänyt {user}",
    "\"remote user\"" : "\"etäkäyttäjä\"",
    "You created {file}" : "Loit tiedoston {file}",
    "You created an encrypted file in {file}" : "Loit salatun tiedoston {file}",
    "{user} created {file}" : "{user} loi tiedoston {file}",
    "{user} created an encrypted file in {file}" : "{user} loi salatun tiedoston {file}",
    "{file} was created in a public folder" : "Tiedosto {file} luotiin julkisessa kansiossa",
    "You changed {file}" : "Muutit tiedostoa {file}",
    "You changed an encrypted file in {file}" : "Muutit salattua tiedostoa {file}",
    "{user} changed {file}" : "{user} muutti tiedostoa {file}",
    "{user} changed an encrypted file in {file}" : "{user} muutti salattua tiedostoa {file}",
    "You deleted {file}" : "Poistit tiedoston {file}",
    "You deleted an encrypted file in {file}" : "Poistit salatun tiedoston {file}",
    "{user} deleted {file}" : "{user} poisti tiedoston {file}",
    "{user} deleted an encrypted file in {file}" : "{user} poisti salatun tiedoston {file}",
    "You restored {file}" : "Palautit tiedoston {file}",
    "{user} restored {file}" : "{user} palautti tiedoston {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Uudelleennimesit tiedoston {oldfile} (piilotettu) tiedostoksi {newfile} (piilotettu)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Uudelleennimesit tiedoston {oldfile} (piilotettu) tiedostoksi {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Uudelleennimesit tiedoston {oldfile} tiedostoksi {newfile} (piilotettu)",
    "You renamed {oldfile} to {newfile}" : "Annoit tiedostolle {oldfile} uuden nimen {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} uudelleennimesi tiedoston {oldfile} (piilotettu) tiedostoksi {newfile} (piilotettu)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} uudelleennimesi tiedoston {oldfile} (piilotettu) tiedostoksi {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} uudelleennimesi tiedoston {oldfile} tiedostoksi {newfile} (piilotettu)",
    "{user} renamed {oldfile} to {newfile}" : "{user} uudelleennimesi tiedoston {oldfile} tiedostoksi {newfile}",
    "You moved {oldfile} to {newfile}" : "Siirsit tiedoston {oldfile} tiedostoksi {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} siirsi tiedoston {oldfile} tiedostoksi {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Tiedosto on lisätty tai poistettu <strong>suosikeista</strong>",
    "A file or folder has been <strong>changed</strong>" : "Tiedostoa tai kansiota on <strong>muutettu</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Suosikkitiedostoa tai -kansiota on <strong>muutettu</strong>",
    "All files" : "Kaikki tiedostot",
    "Upload (max. %s)" : "Lähetys (enintään %s)",
    "Accept" : "Hyväksy",
    "Reject" : "Hylkää",
    "Incoming ownership transfer from {user}" : "Saapuva omistajuussiirto käyttäjältä {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Hyväksytkö kohteen {path}?\n\nHuomio: Siirtotoimenpiteet hyväksynnän jälkeen saattavat kestää tunnin.",
    "Ownership transfer failed" : "Omistajuuden siirto epäonnistui",
    "Your ownership transfer of {path} to {user} failed." : "Kohteen {path} omistajuussiirtosi käyttäjälle {user} epäonnistui.",
    "The ownership transfer of {path} from {user} failed." : "Kohteen {path} omistajuussiirto käyttäjälle {user} epäonnistui.",
    "Ownership transfer done" : "Omistajuuden siirto valmis",
    "Your ownership transfer of {path} to {user} has completed." : "Kohteen {path} omistajuussiirto käyttäjälle {user} valmistui.",
    "The ownership transfer of {path} from {user} has completed." : "Kohteen {path} omistajuussiirto käyttäjältä {user} valmistui.",
    "in %s" : "polussa %s",
    "File Management" : "Tiedostohallinta",
    "Reload current directory" : "Lataa nykyinen kansio uudelleen",
    "Go to the \"{dir}\" directory" : "Siirry kansioon \"{dir}\"",
    "Open folder {name}" : "Avaa kansio {name}",
    "Download file {name}" : "Lataa tiedosto {name}",
    "Select all" : "Valitse kaikki",
    "Storage informations" : "Tallennustilan tietoja",
    "{usedQuotaByte} used" : "{usedQuotaByte} käytetty",
    "{relative}% used" : "{relative} % käytetty",
    "Could not refresh storage stats" : "Tallennustilan tilastoja ei voitu päivittää",
    "Transfer ownership of a file or folder" : "Siirrä tiedoston tai kansion omistajuus",
    "Choose file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
    "Change" : "Muuta",
    "New owner" : "Uusi omistaja",
    "Search for an account" : "Etsi tiliä",
    "Choose a file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
    "Transfer" : "Siirrä",
    "Transfer {path} to {userid}" : "Siirrä {path} käyttäjälle {userid}",
    "Invalid path selected" : "Valittu virheellinen polku",
    "Unknown error" : "Tuntematon virhe",
    "Ownership transfer request sent" : "Pyyntö omistajuuden vaihdosta lähetetty",
    "Cannot transfer ownership of a file or folder you do not own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista",
    "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
    "Loading current folder" : "Ladataan nykyistä kansiota",
    "No files in here" : "Täällä ei ole tiedostoja",
    "No files or folders have been deleted yet" : "Tiedostoja tai kansioita ei ole vielä poistettu",
    "Go to the previous folder" : "Siirry edelliseen kansioon",
    "Go back" : "Mene takaisin",
    "Open the files app settings" : "Avaa tiedostosovelluksen asetukset",
    "Files settings" : "Tiedostojen asetukset",
    "File cannot be accessed" : "Tiedostoa ei voi käyttää",
    "You might not have have permissions to view it, ask the sender to share it" : "Oikeutesi eivät kenties riitä sen katseluun, pyydä lähettäjää jakamaan se",
    "Show hidden files" : "Näytä piilotetut tiedostot",
    "Crop image previews" : "Rajaa kuvien esikatseluja",
    "Additional settings" : "Lisäasetukset",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Kopioi leikepöydälle",
    "Use this address to access your Files via WebDAV" : "Käytä tätä osoitetta yhdistääksesi tiedostosi WebDAV:in kautta",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Jos sinulla on kaksivaiheinen todennus käytössä, sinun täytyy luoda uusi sovellussalasana ja käyttää sitä napsauttamalla tästä.",
    "Clipboard is not available" : "Leikepöytä ei ole käytettävissä",
    "WebDAV URL copied to clipboard" : "WebDAV-osoite kopioitu leikepöydälle",
    "Unable to change the favourite state of the file" : "Suosikki-tilan muuttaminen epäonnistui.",
    "Error while loading the file data" : "Virhe tiedostoa ladatessa",
    "Pick a template for {name}" : "Valtise mallipohja tiedostolle {name}",
    "Cancel" : "Peruuta",
    "Create" : "Luo",
    "Create a new file with the selected template" : "Luo uusi tiedosto valitulla mallipohjalla",
    "Creating file" : "Luodaan tiedostoa",
    "Blank" : "Tyhjä",
    "Unable to create new file from template" : "Uutta tiedostoa mallipohjasta ei voi luoda",
    "Delete permanently" : "Poista pysyvästi",
    "Set up templates folder" : "Aseta mallipohjien kansio",
    "Templates" : "Mallipohjat",
    "Unable to initialize the templates directory" : "Mallipohjien kansiota ei voitu alustaa",
    "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
    "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Upload too large" : "Lähetettävä tiedosto on liian suuri",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Lähetettäväksi valitsemasi tiedostot ylittävät palvelimen salliman tiedostokoon rajan.",
    "No favorites yet" : "Ei vielä suosikkeja",
    "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä",
    "Shares" : "Jaot",
    "Shared with others" : "Jaettu muille",
    "Shared with you" : "Jaettu kanssasi",
    "Shared by link" : "Jaettu linkillä",
    "Deleted shares" : "Poistetut jaot",
    "Pending shares" : "Odottavat jaot",
    "Text file" : "Tekstitiedosto",
    "New text file.txt" : "Uusi tekstitiedosto.txt",
    "Storage invalid" : "Virheellinen tallennustila",
    "Select" : "Valitse",
    "You don’t have permission to upload or create files here" : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai kansioiden luomiseen tähän sijaintiin",
    "New" : "Uusi",
    "Copied!" : "Kopioitu!",
    "Unlimited" : "Rajoittamaton",
    "Search users" : "Etsi käyttäjistä",
    "Cannot transfer ownership of a file or folder you don't own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista",
    "%s used" : "%s käytetty",
    "%s%%" : "%s%%",
    "%1$s of %2$s used" : "%1$s/%2$s käytetty",
    "Settings" : "Asetukset",
    "Deleted files" : "Poistetut tiedostot"
},
"nplurals=2; plural=(n != 1);");
